import Vue from 'vue'
import Router from 'vue-router'
import login from '../views/login'
import register from '../views/register/register'
import manager from '../views/manager/index'
import de from "element-ui/src/locale/lang/de";

Vue.use(Router)

const router = new Router({
  routes: [
    {
      path: '',            // 访问的地址
      redirect: '/login',  // 重定向
      component: login     // 组件名称
    },
    {
      path: '/login',
      name: 'login',
      component: login
    },
    {
      path: '/register',
      name: 'register',
      component: register
    },
    {
      path: '/manager',
      name: 'manager',
      redirect: '/system/welcome',
      component: manager,
      children: [
        {
          path: '/system/welcome',
          name: 'welcome',
          component: () => import("../views/system/welcome")
        },
        {
          // 嵌入页面
          path: '/system/stuIframe',
          name: 'stuIframe',
          component: () => import("../views/system/stuIframe")
        },
        {
          path: '/system/stuMenu',
          name: 'stuMenu',
          component: () => import("../views/system/stuMenu")
        },
        {
          path: '/system/stuClass',
          name: 'stuClass',
          component: () => import("../views/system/stuClass")
        }
      ]
    },
  ]
});

// 导航守卫
// 使用 router.beforeEach 注册一个全局前置守卫，判断用户是否登陆
router.beforeEach((to, from, next) => {
  if (to.path === '/login') {
    next();
  } else {
    let token = localStorage.getItem('Authorization')
    if (token === 'null' || token === '') {
      next('/login');
    } else {
      // 看是否是嵌入页面，嵌入页面url前缀有iframe:
      let path = to.path;
      if (path.indexOf("iframe:") !== -1) {
        // router.push('/system/iframe');
        router.push({path: '/system/stuIframe', query: {url: path}});
      } else {
        next();
      }
    }
  }
});

export default router;
